"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shouldMutateModuleSpecifier = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const typescript_1 = require("typescript");
function shouldMutateModuleSpecifier(source, node, debug, program) {
    var _a;
    if (!typescript_1.isImportDeclaration(node) && !typescript_1.isExportDeclaration(node)) {
        // not "import .. from" or "export .. from"
        return false;
    }
    const moduleSpecifier = node.moduleSpecifier;
    if (!moduleSpecifier || !(moduleSpecifier.kind === typescript_1.SyntaxKind.StringLiteral || typescript_1.isStringLiteral(moduleSpecifier))) {
        debug('  ! syntax error: ', node.getText());
        return false;
    }
    if (moduleSpecifier.text.startsWith('./') || moduleSpecifier.text.startsWith('../')) {
        const dir = path_1.dirname(source);
        for (const ext of ['.ts', '.tsx']) {
            const fp = path_1.resolve(dir, moduleSpecifier.text + ext);
            if (program) {
                if (program.getSourceFile(fp)) {
                    return true;
                }
                else {
                    debug('  ! imported file <%s> not in program');
                }
            }
            else {
                if (fs_1.existsSync(fp)) {
                    return true;
                }
                else {
                    debug('  ! imported file <%s> not exists');
                }
            }
        }
        debug(' ??? ', dir, moduleSpecifier.text);
        return false;
    }
    else {
        // TODO: handle paths mapping (absolute to tsconfig.json)
        debug('absolute import: %s', (_a = node.moduleSpecifier) === null || _a === void 0 ? void 0 : _a.getText());
        return false;
    }
}
exports.shouldMutateModuleSpecifier = shouldMutateModuleSpecifier;
//# sourceMappingURL=shouldMutateModuleSpecifier.js.map